@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright (C) 2014 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include <fcntl.h>
 #include <gcrypt.h>
@@ -70,14 +58,15 @@
 #define KWALLET_PAM_SALTSIZE 56
 #define KWALLET_PAM_ITERATIONS 50000
 
+// Parameters
 const static char *kdehome = NULL;
 const static char *kwalletd = NULL;
 const static char *socketPath = NULL;
-const static char *kwalletPamDataKey = NULL;
-const static char *logPrefix = NULL;
 static int force_run = 0;
 
-const static char *envVar = "PAM_KWALLET5_LOGIN";
+const static char * const kwalletPamDataKey = "kwallet5_key";
+const static char * const logPrefix = "pam_kwallet5";
+const static char * const envVar = "PAM_KWALLET5_LOGIN";
 
 static int argumentsParsed = -1;
 
@@ -108,12 +97,6 @@ static void parseArguments(int argc, const char **argv)
     if (kwalletd == NULL) {
         kwalletd = KWALLETD_BIN_PATH;
     }
-    if (kwalletPamDataKey == NULL) {
-        kwalletPamDataKey = "kwallet5_key";
-    }
-    if (logPrefix == NULL) {
-        logPrefix = "pam_kwallet5";
-    }
 }
 
 static const char* get_env(pam_handle_t *ph, const char *name)
@@ -240,7 +223,7 @@ static int is_graphical_session(pam_handle_t *pamh)
 {
     //Detect a graphical session
     const char *pam_tty = NULL, *pam_xdisplay = NULL,
-               *xdg_session_type = NULL, *display = NULL;
+               *xdg_session_type = NULL;
 
     pam_get_item(pamh, PAM_TTY, (const void**) &pam_tty);
 #ifdef PAM_XDISPLAY
@@ -372,18 +355,16 @@ static void execute_kwallet(pam_handle_t *pamh, struct passwd *userInfo, int toW
     //Change to the user in case we are not it yet
     if (drop_privileges(userInfo) < 0) {
         syslog(LOG_ERR, "%s: could not set gid/uid/euid/egit for kwalletd", logPrefix);
-        free(fullSocket);
         goto cleanup;
     }
 
     int envSocket;
     if ((envSocket = socket(AF_UNIX, SOCK_STREAM, 0)) == -1) {
         syslog(LOG_ERR, "%s: couldn't create socket", logPrefix);
-        free(fullSocket);
         goto cleanup;
     }
 
-    struct sockaddr_un local;
+    struct sockaddr_un local = {};
     local.sun_family = AF_UNIX;
 
     if (strlen(fullSocket) > sizeof(local.sun_path)) {
@@ -393,14 +374,11 @@ static void execute_kwallet(pam_handle_t *pamh, struct passwd *userInfo, int toW
         goto cleanup;
     }
     strcpy(local.sun_path, fullSocket);
-    free(fullSocket);
-    fullSocket = NULL;
     unlink(local.sun_path);//Just in case it exists from a previous login
 
     syslog(LOG_DEBUG, "%s: final socket path: %s", logPrefix, local.sun_path);
 
-    size_t len = strlen(local.sun_path) + sizeof(local.sun_family);
-    if (bind(envSocket, (struct sockaddr *)&local, len) == -1) {
+    if (bind(envSocket, (struct sockaddr *)&local, sizeof(local)) == -1) {
         syslog(LOG_INFO, "%s-kwalletd: Couldn't bind to local file\n", logPrefix);
         goto cleanup;
     }
@@ -503,6 +481,7 @@ static void start_kwallet(pam_handle_t *pamh, struct passwd *userInfo, const cha
     switch (pid = fork ()) {
     case -1:
         pam_syslog(pamh, LOG_ERR, "%s: Couldn't fork to execv kwalletd", logPrefix);
+        free(fullSocket);
         return;
 
     //Child fork, will contain kwalletd
@@ -521,6 +500,8 @@ static void start_kwallet(pam_handle_t *pamh, struct passwd *userInfo, const cha
         break;
     };
 
+    free(fullSocket);
+
     close(toWalletPipe[0]);//Read end of the pipe, we will only use the write
     if (better_write(toWalletPipe[1], kwalletKey, KWALLET_PAM_KEYSIZE) < 0) {
         pam_syslog(pamh, LOG_ERR, "%s: Impossible to write walletKey to walletPipe", logPrefix);
